@@ -24,6 +24,8 @@ package Vend::Accounting::SQL_Ledger;
 
 use strict;
 use warnings;
+use utf8;
+
 use Vend::Util;
 use Vend::Accounting;
 use Text::ParseWords;
@@ -1229,28 +1231,28 @@ sub format_string {
   # order matters!!!
   my %umlaute = ( 'order' => { 'html' => [ '&', '<', '>', quotemeta('\n'), '
 ',
-                                           '', '', '',
-					   '', '', '',
-					   '' ],
+                                           'ä', 'ö', 'ü',
+					   'Ä', 'Ö', 'Ü',
+					   'ß' ],
                                'tex'  => [ '&', quotemeta('\n'), '
 ',
-			                   '', '', '',
-					   '', '', '',
-					   '', '\$', '%' ] },
+			                   'ä', 'ö', 'ü',
+					   'Ä', 'Ö', 'Ü',
+					   'ß', '\$', '%' ] },
                   'html' => {
                 '&' => '&amp;', '<' => '&lt;', '>' => '&gt;', quotemeta('\n') => '<br>', '
 ' => '<br>',
-                '' => '&auml;', '' => '&ouml;', '' => '&uuml;',
-	        '' => '&Auml;', '' => '&Ouml;', '' => '&Uuml;',
-	        '' => '&szlig;',
+                'ä' => '&auml;', 'ö' => '&ouml;', 'ü' => '&uuml;',
+	        'Ä' => '&Auml;', 'Ö' => '&Ouml;', 'Ü' => '&Uuml;',
+	        'ß' => '&szlig;',
 	        '\x84' => '&auml;', '\x94' => '&ouml;', '\x81' => '&uuml;',
 	        '\x8e' => '&Auml;', '\x99' => '&Ouml;', '\x9a' => '&Uuml;',
 	        '\xe1' => '&szlig;'
 		            },
 	          'tex' => {
-	        '' => '\"a', '' => '\"o', '' => '\"u',
-	        '' => '\"A', '' => '\"O', '' => '\"U',
-	        '' => '{\ss}',
+	        'ä' => '\"a', 'ö' => '\"o', 'ü' => '\"u',
+	        'Ä' => '\"A', 'Ö' => '\"O', 'Ü' => '\"U',
+	        'ß' => '{\ss}',
 	        '\x84' => '\"a', '\x94' => '\"o', '\x81' => '\"u',
 	        '\x8e' => '\"A', '\x99' => '\"O', '\x9a' => '\"U',
 	        '\xe1' => '{\ss}',
