@@ -1,8 +1,6 @@
 # Vend::Cart - Interchange shopping cart management routines
 #
-# $Id: Cart.pm,v 2.26 2009-05-20 22:13:32 pajamian Exp $
-#
-# Copyright (C) 2002-2009 Interchange Development Group
+# Copyright (C) 2002-2011 Interchange Development Group
 # Copyright (C) 1996-2002 Red Hat, Inc.
 #
 # This program was originally based on Vend 0.2 and 0.3
@@ -25,7 +23,7 @@
 
 package Vend::Cart;
 
-$VERSION = substr(q$Revision: 2.26 $, 10);
+$VERSION = '2.27';
 
 use strict;
 
@@ -262,8 +260,8 @@ sub toss_cart {
 				  $tab = $item->{mv_ib} || $Vend::Cfg->{ProductFiles}[0];
 			      }
 
-			      my ($prefix) = $tab =~ s/^([=\?])//;
-			      $prefix ||= '';
+			      my $prefix = '';
+			      $tab =~ s/^([=?])// and $prefix = $1;
 
 			      my $max = \$quantity_cache{"$tab.$col.$item->{code}"};
 			      $$max ||= ::tag_data($tab, $col, $item->{code});
@@ -275,7 +273,7 @@ sub toss_cart {
 				  last MAX_QUANTITY;
 			      }
 
-			      elsif ($prefix = '?') {
+			      elsif ($prefix eq '?') {
 				  next QUANTITY_FIELD if !defined $$max || $$max <= 0;
 				  $$mv_max = $$max;
 				  last QUANTITY_ADJUST;
