@@ -306,8 +306,9 @@ sub import_text {
 			or die ::errmsg("No absolute file names like '%s' allowed.\n", $fn);
 	}
 	else {
-		Vend::Util::writefile($fn, $text)
-			or die ("Cannot write temporary import file $fn: $!\n");
+		# data is already in memory, do not create a temporary file
+		$options->{scalar_ref} = 1;
+		$fn = \$text;
 	}
 
 	my $save = $/;
@@ -319,7 +320,7 @@ sub import_text {
 	Vend::Table::Common::import_ascii_delimited($fn, $options);
 
 	$/ = $save;
-	unlink $fn unless $options->{'file'};
+	unlink $fn unless $options->{'file'} or $options->{scalar_ref};
 	return 1;
 }
 
