@@ -31,8 +31,8 @@ use File::Copy;
 use File::Basename;
 use Sys::Hostname;
 use Vend::Util;
-require Safe;
-$Safe = new Safe;
+require Vend::Safe;
+$Safe = new Vend::Safe;
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -543,7 +543,7 @@ sub readconfig {
 				
 					([^>\n]+)
 				\s*>\s+
-					([\000-\377]*?)
+					((?s:.)*?)
 				</catalog>!
 				$virtual{$1} = $2; ''!xieg;
 
@@ -2112,7 +2112,7 @@ sub conf_parse_http {
 				\s+
 					([^>\n]+)
 				\s*>\s+
-					([\000-\377]*?)
+					((?s:.)*?)
 				</virtualhost>!
 				$virtual->{$1} = $2; ''!xieg;
 
