@@ -126,6 +126,7 @@ my %Parse = (
 								my($ref,$params) = @_;
 								my ($var, $value) = split /\s+/, $params, 2;
 								$::Values->{$var} = $value;
+								return 1;
 							},
 	'&setcheck'			=>	sub {		
 								my($ref,$params) = @_;
@@ -1116,7 +1117,7 @@ $state_template{CA} = <<EOF;
 EOF
 
 $zip_error{US} = "'%s' not a US zip code";
-$zip_routine{US} = sub { $_[0] =~ /^\s*\d\d\d\d\d(?:-?\d\d\d\d)?$/ };
+$zip_routine{US} = sub { $_[0] =~ /^\s*\d\d\d\d\d(?:-?\d\d\d\d)?\s*$/ };
 
 $zip_error{CA} = "'%s' not a Canadian postal code";
 $zip_routine{CA} = sub {
