@@ -1,6 +1,6 @@
 # Vend::SessionFile - Stores Interchange session information in files
 #
-# $Id: SessionFile.pm,v 2.7 2007-12-04 01:57:44 markj Exp $
+# $Id: SessionFile.pm,v 2.8 2009-04-16 16:58:31 mheins Exp $
 #
 # Copyright (C) 2002-2007 Interchange Development Group
 # Copyright (C) 1996-2002 Red Hat, Inc.
@@ -29,7 +29,7 @@ use strict;
 use Vend::Util;
 
 use vars qw($VERSION);
-$VERSION = substr(q$Revision: 2.7 $, 10);
+$VERSION = substr(q$Revision: 2.8 $, 10);
 
 my $SessionDir;
 my $CommDir;
@@ -56,7 +56,7 @@ sub TIEHASH {
 }
 
 sub keyname {
-	return Vend::Util::get_filename(shift, 2, 1, $SessionDir);
+	return Vend::Util::get_filename(shift, $Vend::Cfg->{SessionHashLevels}, $Vend::Cfg->{SessionHashLength}, $SessionDir);
 }
 
 sub FETCH {
