@@ -1046,7 +1046,9 @@ sub import_ascii_delimited {
 
 	my $realfile;
 	if($options->{PRELOAD}) {
-		if (-f $infile and $options->{PRELOAD_EMPTY_ONLY}) {
+		# do not preload if $infile is a scalar reference
+		if ($options->{scalar_ref} or 
+			(-f $infile and $options->{PRELOAD_EMPTY_ONLY})) {
 			# Do nothing, no preload
 		}
 		else {
@@ -1058,10 +1060,18 @@ sub import_ascii_delimited {
 	}
 
 	if(! defined $realfile) {
-		open(IN, "+<$infile")
-			or die errmsg("%s %s: %s\n", errmsg("open read/write"), $infile, $!);
-		lockfile(\*IN, 1, 1)
-			or die errmsg("%s %s: %s\n", errmsg("lock"), $infile, $!);
+		if($options->{scalar_ref}){
+			open(IN, '+<', $infile)
+				or die errmsg("%s %s: %s\n", errmsg("open scalar reference"), *$infile, $!);
+			# locking of scalar reference filehandles in unsupported
+		}
+		else{
+			open(IN, "+<$infile")
+				or die errmsg("%s %s: %s\n", errmsg("open read/write"), $infile, $!);
+			lockfile(\*IN, 1, 1)
+				or die errmsg("%s %s: %s\n", errmsg("lock"), $infile, $!);
+		}
+
 	}
 	else {
 		open(IN, "<$infile")
@@ -1474,7 +1484,9 @@ EndOfRoutine
 	}
 	delete $out->[$CONFIG]{Clean_start};
 	delete $out->[$CONFIG]{_Dirty};
-	unlockfile(\*IN) or die "unlock\n";
+	unless($options->{scalar_ref}){
+		unlockfile(\*IN) or die "unlock\n";
+	}
     close(IN);
 	my $dot = $out->[$CONFIG]{HIDE_AUTO_FILES} ? '.' : '';
 	if($numeric_guess) {
@@ -1636,7 +1648,7 @@ sub log_error {
 
 sub new_filehandle {
 	my $fh = shift;
-	binmode($fh, ":utf8") if $::Variable->{MV_UTF8};
+	binmode($fh, ":utf8") if $::Variable->{MV_UTF8} || $Global::Variable->{MV_UTF8};
 	return $fh;
 }
 
