@@ -56,6 +56,7 @@ my %Cattr = ( qw(
 					RAISEERROR     	RaiseError
 					PRINTERROR     	PrintError
 					AUTOCOMMIT     	AutoCommit
+					MYSQL_ENABLE_UTF8 mysql_enable_utf8
 				) );
 my @Cattr = keys %Cattr;
 
@@ -1739,8 +1740,10 @@ sub delete_record {
 						);
 		return undef;
 	}
-	$key = $s->[$DBI]->quote($key)
-		unless exists $s->[$CONFIG]{NUMERIC}{$s->[$KEY]};
+
+	## Rely on DBI to quote
+	$key = $s->[$DBI]->quote($key, $s->[$KEY]);
+
     $s->[$DBI]->do("delete from $s->[$TABLE] where $s->[$KEY] = $key");
 }
 
