@@ -29,7 +29,11 @@ use vars qw($VERSION @ISA);
 use GDBM_File;
 use Vend::Table::Common;
 
-unless( $ENV{MINIVEND_DISABLE_UTF8} ) {
+if ($ENV{MINIVEND_DISABLE_UTF8}) {
+	sub encode($$;$){}
+	sub decode($$;$){}
+}
+else {
 	require Encode;
 	import Encode qw( decode encode );
 }
@@ -62,8 +66,6 @@ sub create {
 	my $dbm = tie(%$tie, 'GDBM_File', $filename, $flags, $File_permission_mode)
 		or die ::errmsg("%s %s: %s\n", ::errmsg("create"), $filename, $!);
 
-	apply_utf8_filters($dbm) if $config->{GDBM_ENABLE_UTF8};
-
 	$tie->{'c'} = join("\t", @$columns);
 
 	my $s = [
