@@ -335,8 +335,10 @@ sub picture_format {
     $pic	= reverse $pic;
 	$point	= '.' unless defined $point;
 	$sep	= ',' unless defined $sep;
-	$pic =~ /(#+)\Q$point/;
-	my $len = length($1);
+	my $len = $pic =~ /(#+)\Q$point/
+		? length($1)
+		: 0
+	;
 	$amount = sprintf('%.' . $len . 'f', $amount);
 	$amount =~ tr/0-9//cd;
 	my (@dig) = split m{}, $amount;
@@ -686,6 +688,13 @@ eval {
 	die unless $ENV{MINIVEND_STORABLE};
 	require Storable;
 	import Storable 'freeze';
+
+	if ($ENV{MINIVEND_STORABLE_CODE}) {
+		# allow code references to be stored to the session
+		 $Storable::Deparse = 1;
+		 $Storable::Eval = 1;
+	}
+
 	$Fast_uneval     = \&Storable::freeze;
 	$Fast_uneval_file  = \&Storable::store;
 	$Eval_routine    = \&Storable::thaw;
@@ -1179,7 +1188,7 @@ sub readin {
 
 		if (open(MVIN, "< $fn")) {
 			binmode(MVIN) if $Global::Windows;
-			binmode(MVIN, ":utf8") if $::Variable->{MV_UTF8};
+			binmode(MVIN, ":utf8") if $::Variable->{MV_UTF8} || $Global::Variable->{MV_UTF8};
 			undef $/;
 			$contents = <MVIN>;
 			close(MVIN);
@@ -1277,7 +1286,7 @@ sub vendUrl {
 	$ct = ++$Vend::Session->{pageCount}
 		unless $opt->{no_count};
 
-	if($opt->{no_session}) {
+	if($opt->{no_session} or $::Pragma->{url_no_session_id}) {
 		undef $id;
 		undef $ct;
 	}
@@ -1316,6 +1325,11 @@ sub vendUrl {
 		$opt->{anchor} =~ s/^#//;
 		$r .= '#' . $opt->{anchor};
 	}
+
+	# return full-path portion of the URL
+	if ($opt->{path_only}) {
+		$r =~ s!^https?://[^/]*!!i;
+	}
 	return $r;
 } 
 
@@ -1992,7 +2006,7 @@ sub read_cookie {
 	my ($lookfor, $string) = @_;
 	$string = $CGI::cookie
 		unless defined $string;
-	return undef unless $string =~ /\b$lookfor=([^\s;]+)/i;
+    return undef unless $string =~ /(?:^|;)\s*\Q$lookfor\E=([^\s;]+)/i;
  	return unescape_chars($1);
 }
 
@@ -2017,7 +2031,7 @@ sub send_mail {
 				$to = $1;
 			}
 			elsif (/^Reply-to:\s*(.+)/si) {
-				$reply = $_;
+				$reply = $1;
 			}
 			elsif (/^subj(?:ect)?:\s*(.+)/si) {
 				$subject = $1;
